@@ -1,24 +1,12 @@
 package Math::GrahamFunction;
-
+$Math::GrahamFunction::VERSION = '0.02002';
 use warnings;
 use strict;
 
 use 5.008;
 
-=head1 NAME
 
-Math::GrahamFunction - Calculate the Graham's Function of a Natural
-Number.
-
-=head1 VERSION
-
-Version 0.02000
-
-=cut
-
-our $VERSION = '0.02001';
-
-use base qw(Math::GrahamFunction::Object);
+use parent qw(Math::GrahamFunction::Object);
 
 use Math::GrahamFunction::SqFacts;
 use Math::GrahamFunction::SqFacts::Dipole;
@@ -45,60 +33,6 @@ sub _initialize
     return 0;
 }
 
-=head1 SYNOPSIS
-
-    use Math::GrahamFunction;
-
-    my $calc = Math::GrahamFunction->new({ 'n' => 500 });
-
-    my $results = $calc->solve();
-
-    print "The Graham Function of 500 is ",
-        $results->{'factors'}->[-1],
-        "\n";
-
-=head1 DESCRIPTION
-
-The Graham Function of a natural number B<n>, which we will denote by B<G(n)>,
-is the minimal number for which there's an increasing series of integers
-that starts at B<n> and ends at B<G(n)> whose product is a perfect square.
-
-This module calculates the Graham Function of a natural number, along with
-the entire associated series.
-
-=head2 BACKGROUND
-
-On 11 December 2002, Mark Jason Dominus gave a Perl Quiz-of-the-week
-challenge to write a Perl program to calculate the Graham Function. I came
-up with a solution for it, whose complexity was polynomial (as opposed to
-brute force solutions, which are exponential complexity.). This module is
-derived from my original code, after it was heavily refactored.
-
-More information about the algorithm and the original code can be found here:
-
-L<http://www.shlomifish.org/lecture/Perl/Graham-Function/>
-
-=head1 FUNCTIONS
-
-=head2 my $calc = Math::GrahamFunction->new({'n' => $n});
-
-Initializes a new object for solving the Graham's Function of the
-number C<$n>. Call solve() next.
-
-=head2 my $results = $calc->solve();
-
-Calculates the Graham's Function series for the number (could be
-time consuming), and returns a hash ref of results. The only field
-of interest there is C<'factors'>, which points to an array reference
-of the series. The series is increasing so
-C<$results->{factors}->[0]> is C<$n> and
-C<$results->{factors}->[-1]} is the Graham's Function.
-
-=head2 $self->_get_num_facts($number)
-
-Get the Square factors of the number $number.
-
-=cut
 
 sub _get_num_facts
 {
@@ -308,25 +242,6 @@ sub _main_init
     return;
 }
 
-=begin none
-
-# A method to print the base. It is not used but can prove useful for
-# debugging.
-sub _print_base
-{
-    my $self = shift;
-    print "Base=\n\n";
-    for(my $j = 0 ; $j < scalar( @{$self->_base()} ) ; $j++)
-    {
-        next if (! defined($self->_base->[$j]));
-        print "base[$j] (" . join(" * ", @{$self->_base->[$j]}) . ")\n";
-    }
-    print "\n\n";
-};
-
-=end none
-
-=cut
 
 sub _update_base
 {
@@ -447,6 +362,95 @@ sub _main_solve
     }
 }
 
+
+1; # End of Math::GrahamFunction
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Math::GrahamFunction - Calculate the Graham's Function of a Natural
+Number.
+
+=head1 VERSION
+
+version 0.02002
+
+=head1 SYNOPSIS
+
+    use Math::GrahamFunction;
+
+    my $calc = Math::GrahamFunction->new({ 'n' => 500 });
+
+    my $results = $calc->solve();
+
+    print "The Graham Function of 500 is ",
+        $results->{'factors'}->[-1],
+        "\n";
+
+=head1 DESCRIPTION
+
+The Graham Function of a natural number B<n>, which we will denote by B<G(n)>,
+is the minimal number for which there's an increasing series of integers
+that starts at B<n> and ends at B<G(n)> whose product is a perfect square.
+
+This module calculates the Graham Function of a natural number, along with
+the entire associated series.
+
+=head2 BACKGROUND
+
+On 11 December 2002, Mark Jason Dominus gave a Perl Quiz-of-the-week
+challenge to write a Perl program to calculate the Graham Function. I came
+up with a solution for it, whose complexity was polynomial (as opposed to
+brute force solutions, which are exponential complexity.). This module is
+derived from my original code, after it was heavily refactored.
+
+More information about the algorithm and the original code can be found here:
+
+L<http://www.shlomifish.org/lecture/Perl/Graham-Function/>
+
+=head1 VERSION
+
+version 0.02002
+
+=head1 FUNCTIONS
+
+=head2 my $calc = Math::GrahamFunction->new({'n' => $n});
+
+Initializes a new object for solving the Graham's Function of the
+number C<$n>. Call solve() next.
+
+=head2 my $results = $calc->solve();
+
+Calculates the Graham's Function series for the number (could be
+time consuming), and returns a hash ref of results. The only field
+of interest there is C<'factors'>, which points to an array reference
+of the series. The series is increasing so
+C<$results->{factors}->[0]> is C<$n> and
+C<$results->{factors}->[-1]} is the Graham's Function.
+
+=head2 $self->_get_num_facts($number)
+
+Get the Square factors of the number $number.
+
+=for none # A method to print the base. It is not used but can prove useful for
+# debugging.
+sub _print_base
+{
+    my $self = shift;
+    print "Base=\n\n";
+    for(my $j = 0 ; $j < scalar( @{$self->_base()} ) ; $j++)
+    {
+        next if (! defined($self->_base->[$j]));
+        print "base[$j] (" . join(" * ", @{$self->_base->[$j]}) . ")\n";
+    }
+    print "\n\n";
+};
+
 =head1 AUTHOR
 
 Shlomi Fish, C<< <shlomif at cpan.org> >>
@@ -519,6 +523,132 @@ B<Note:> the module meta-data says this module is released under the BSD
 license. However, MIT X11 is the more accurate license, and "bsd" is
 the closest option for the CPAN meta-data.
 
-=cut
+=head1 AUTHOR
 
-1; # End of Math::GrahamFunction
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/math-grahamfunction/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Math::GrahamFunction
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Math-GrahamFunction>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Math-GrahamFunction>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Math-GrahamFunction>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Math-GrahamFunction>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Math-GrahamFunction>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Math-GrahamFunction>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/M/Math-GrahamFunction>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Math-GrahamFunction>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Math::GrahamFunction>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-math-grahamfunction at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Math-GrahamFunction>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/math-grahamfunction>
+
+  git clone https://bitbucket.org/shlomif/perl-math-grahamfunction/
+
+=cut
